diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/erts/config.h.in otp_src_P9C_2003-07-10.fixed/erts/config.h.in
--- otp_src_P9C_2003-07-10/erts/config.h.in	2003-07-10 09:05:47.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/erts/config.h.in	2003-07-11 11:26:27.000000000 +0200
@@ -41,6 +41,9 @@
 /* Define if you have the ANSI C header files.  */
 #undef STDC_HEADERS
 
+/* Define if you have the sstream C++ header */
+#undef HAVE_SSTREAM
+
 /* Define if you can safely include both <sys/time.h> and <time.h>.  */
 #undef TIME_WITH_SYS_TIME
 
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/erts/configure.in otp_src_P9C_2003-07-10.fixed/erts/configure.in
--- otp_src_P9C_2003-07-10/erts/configure.in	2003-07-09 11:39:45.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/erts/configure.in	2003-07-11 11:32:25.000000000 +0200
@@ -182,6 +182,19 @@
   #WFLAGS="-Wall -Wshadow -Wcast-qual -Wmissing-declarations"
   WFLAGS="-Wall -Wstrict-prototypes -Wmissing-prototypes"
   #WFLAGS=""
+  # check which GCC version
+  GCC_VERSION=`$CC -v 2>&1 | sed -n 's/gcc version //p'`
+  # GCC 3.3 and later supports C99 strict aliasing
+  # until all source is compliant with strict aliasing we disable it
+  case "$GCC_VERSION" in
+    1*) ;;
+    2*) ;;
+    3.0*) ;; 
+    3.1*) ;;
+    3.2*) ;;
+    *)
+        WFLAGS="$WFLAGS -fno-strict-aliasing";;
+  esac
 else
   WFLAGS=""
 fi
@@ -1185,6 +1198,42 @@
     CRYPTO_APP=crypto
 fi
 
+if test "x$SSL_INCLUDE" != "x" ; then
+    dnl We found openssl, now check if we use kerberos 5 support
+    AC_MSG_CHECKING(for OpenSSL kerberos 5 support)
+    old_CPPFLAGS=$CPPFLAGS
+    CPPFLAGS=$SSL_INCLUDE
+    AC_EGREP_CPP(yes,[
+#include <openssl/opensslconf.h>
+#ifndef OPENSSL_NO_KRB5
+  yes
+#endif
+      ],[
+      AC_MSG_RESULT([yes])
+      ssl_krb5_enabled=yes
+      ],[
+      AC_MSG_RESULT([no])
+      ssl_krb5_enabled=no
+      ])
+    CPPFLAGS=$old_CPPFLAGS
+    SSL_KRB5_INCLUDE=
+    if test "x$ssl_krb5_enabled" = "xyes" ; then
+        AC_MSG_CHECKING(for krb5.h in standard locations)
+	for dir in $extra_dir $SSL_ROOT/include $SSL_ROOT/include/openssl $SSL_ROOT/include/kerberos \
+		       /cygdrive/c/kerberos/include /usr/local/kerberos/include /usr/kerberos/include
+            do
+            if test -f "$dir/krb5.h" ; then
+                SSL_KRB5_INCLUDE="$dir"
+            fi
+            done
+        if test "x$SSL_KRB5_INCLUDE" = "x" ; then
+	    AC_MSG_ERROR([OpenSSL is configured for kerberos but no krb5.h found])
+        else
+            AC_MSG_RESULT([found in $SSL_KRB5_INCLUDE])
+            SSL_INCLUDE="$SSL_INCLUDE -I$SSL_KRB5_INCLUDE"
+        fi
+    fi
+fi
 
 #--------------------------------------------------------------------
 # Os mon stuff.
@@ -1231,8 +1280,9 @@
 dnl Orber has a c++ example, this isn't the right way to check for
 dnl it, but....
 dnl
-CXXFLAGS=
+CXXFLAGS="$extra_flags"
 AC_SUBST(CXXFLAGS)
+
 dnl this deliberately does not believe that 'gcc' is a C++ compiler
 AC_CHECK_PROGS(CXX, $CCC c++ g++ CC cxx cc++ cl, false)
 
@@ -1241,6 +1291,16 @@
 
 if test "$CXX" = false; then
   echo "No C++ compiler found" > $ERL_TOP/lib/orber/SKIP
+else
+  AC_LANG_CPLUSPLUS
+  AC_TRY_COMPILE(
+#include <sstream>
+,
+	[],
+	AC_DEFINE(HAVE_SSTREAM)
+	AC_MSG_RESULT([checking for sstream ... yes]),
+	AC_MSG_RESULT([checking for sstream ... no]))
+   AC_LANG_C
 fi
 
 #
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/erts/emulator/beam/elib_malloc.c otp_src_P9C_2003-07-10.fixed/erts/emulator/beam/elib_malloc.c
--- otp_src_P9C_2003-07-10/erts/emulator/beam/elib_malloc.c	2003-07-07 14:04:05.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/erts/emulator/beam/elib_malloc.c	2003-07-11 08:25:41.000000000 +0200
@@ -197,6 +197,14 @@
 void elib_force_init(EWord *, EWord);
 #endif
 
+#if defined(__STDC__)
+/* define prototypes for missing */
+void* memalign(size_t a, size_t s);
+void* pvalloc(size_t nb);
+void* memresize(void *p, int nb);
+int memsize(void *p);
+#endif
+
 /* bytes to pages */
 #define PAGES(x)      (((x)+page_size-1) / page_size)
 #define PAGE_ALIGN(p) ((char*)((((EWord)(p))+page_size-1)&~(page_size-1)))
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/erts/emulator/beam/erl_db_util.c otp_src_P9C_2003-07-10.fixed/erts/emulator/beam/erl_db_util.c
--- otp_src_P9C_2003-07-10/erts/emulator/beam/erl_db_util.c	2003-07-07 14:10:21.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/erts/emulator/beam/erl_db_util.c	2003-07-11 09:27:22.000000000 +0200
@@ -604,7 +604,9 @@
 */
 /* Utility code */
 static DMCGuardBif *dmc_lookup_bif(Eterm t, int arity);
+#ifdef DMC_DEBUG
 static Eterm dmc_lookup_bif_reversed(void *f);
+#endif
 static int cmp_uint(void *a, void *b);
 static int cmp_guard_bif(void *a, void *b);
 static int match_compact(ErlHeapFragment *expr, DMCErrInfo *err_info);
@@ -3671,6 +3673,7 @@
 		   (int (*)(const void *, const void *)) &cmp_guard_bif); 
 }
 
+#ifdef DMC_DEBUG
 static Eterm dmc_lookup_bif_reversed(void *f)
 {
     int i;
@@ -3679,6 +3682,7 @@
 	    return guard_tab[i].name;
     return am_undefined;
 }
+#endif
 
 /* For sorting. */
 static int cmp_uint(void *a, void *b) 
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/erts/emulator/drivers/common/zlib_drv.c otp_src_P9C_2003-07-10.fixed/erts/emulator/drivers/common/zlib_drv.c
--- otp_src_P9C_2003-07-10/erts/emulator/drivers/common/zlib_drv.c	2003-07-07 14:23:38.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/erts/emulator/drivers/common/zlib_drv.c	2003-07-11 07:56:23.000000000 +0200
@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <zlib.h>
 #include <errno.h>
+#include <string.h>
 
 #include "erl_driver.h"
 
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/lib/erl_interface/configure.in otp_src_P9C_2003-07-10.fixed/lib/erl_interface/configure.in
--- otp_src_P9C_2003-07-10/lib/erl_interface/configure.in	2003-07-07 14:12:51.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/lib/erl_interface/configure.in	2003-07-11 10:22:46.000000000 +0200
@@ -256,6 +256,30 @@
 fi
 
 # ---------------------------------------------------------------------------
+# Warning flags to the C compiler
+# ---------------------------------------------------------------------------
+AC_SUBST(WFLAGS)
+
+if test "x$GCC" = xyes; then
+  WFLAGS="-Wall -Wstrict-prototypes -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Winline"
+  # check which GCC version
+  GCC_VERSION=`$CC -v 2>&1 | sed -n 's/gcc version //p'`
+  # GCC 3.3 and later supports C99 strict aliasing
+  # until all source is compliant with strict aliasing we disable it
+  case "$GCC_VERSION" in
+    1*) ;;
+    2*) ;;
+    3.0*) ;; 
+    3.1*) ;;
+    3.2*) ;;
+    *)
+        WFLAGS="$WFLAGS -fno-strict-aliasing";;
+  esac
+else
+  WFLAGS=""
+fi
+
+# ---------------------------------------------------------------------------
 # FIXME We want to use libtool but until then....
 # ---------------------------------------------------------------------------
 
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/lib/erl_interface/src/Makefile.in otp_src_P9C_2003-07-10.fixed/lib/erl_interface/src/Makefile.in
--- otp_src_P9C_2003-07-10/lib/erl_interface/src/Makefile.in	2003-07-07 14:04:30.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/lib/erl_interface/src/Makefile.in	2003-07-11 10:09:50.000000000 +0200
@@ -89,10 +89,7 @@
 ifeq ($(TARGET),win32)
 WARNFLAGS = -Wall
 else
-WARNFLAGS = \
-	-Wall -Wstrict-prototypes \
-	-Wmissing-prototypes -Wmissing-declarations \
-	-Wnested-externs -Winline
+WARNFLAGS = @WFLAGS@
 endif
 
 ifneq ($(findstring ose,$(TARGET)),ose)
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/lib/orber/c_src/InitialReference.cc otp_src_P9C_2003-07-10.fixed/lib/orber/c_src/InitialReference.cc
--- otp_src_P9C_2003-07-10/lib/orber/c_src/InitialReference.cc	2000-08-22 13:54:03.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/lib/orber/c_src/InitialReference.cc	2003-07-11 11:33:59.000000000 +0200
@@ -44,12 +44,12 @@
    */
 char* InitialReference::stringified_ior(char* newhost, int newport)
 {
-  strstream iorByteString;
-  strstream profileData;
+  STRINGSTREAM iorByteString;
+  STRINGSTREAM profileData;
 
-  strstreambuf *s;
-  strstreambuf *profileDataBuf;
-  strstreambuf *iorByteStringBuf;
+  STRINGBUF *s;
+  STRINGBUF *profileDataBuf;
+  STRINGBUF *iorByteStringBuf;
   long profileDataLength = 0;
   char *str;
 
@@ -95,7 +95,7 @@
   profileDataLength += 2;
   
   profileDataLength = align(profileDataBuf, profileDataLength, 4);
-  
+
   profileDataBuf->sputn(iorBytesLastPart, 8);
   profileDataLength += 8;
   //cout << "pd length: " << profileDataLength << "\n";
@@ -108,9 +108,13 @@
 
   iorByteStringBuf->sputn(iorBytesFirstPart, 48);
   iorByteStringBuf->sputn(profileDataLengthBytes, 4);
+#ifdef HAVE_SSTREAM
+  iorByteStringBuf->sputn(profileData.str().data(), profileDataLength);
+#else
   str = profileData.str();
   iorByteStringBuf->sputn(str, profileDataLength);
   delete str;
+#endif
 
   createIOR(iorByteString, 48 + 4 + profileDataLength);
 
@@ -136,14 +140,19 @@
   return;
 }
 
-void InitialReference::createIOR(strstream& byte, long length)
+void InitialReference::createIOR(STRINGSTREAM& byte, long length)
 {
-  strstreambuf *stringbuf;
-  strstream string;
+  STRINGBUF *stringbuf;
+  STRINGSTREAM string;
 
   int i;
+#ifdef HAVE_SSTREAM
+  const char *c;
+  const char *bytestr = byte.str().c_str();
+#else
   char *c;
   char *bytestr = byte.str();
+#endif
   int b, n1, n2, c1, c2;
 
   stringbuf = string.rdbuf();
@@ -167,12 +176,16 @@
 
   delete bytestr;
 
+#ifdef HAVE_SSTREAM
+  iorString = (char *)string.str().c_str();
+#else
   iorString = string.str();
+#endif
       
   return;
 }
 
-long InitialReference::align(strstreambuf* sbuf, long currentLength, 
+long InitialReference::align(STRINGBUF* sbuf, long currentLength, 
 			    int alignment)
 {
   long length = currentLength;
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/lib/orber/c_src/InitialReference.hh otp_src_P9C_2003-07-10.fixed/lib/orber/c_src/InitialReference.hh
--- otp_src_P9C_2003-07-10/lib/orber/c_src/InitialReference.hh	1999-10-21 15:35:14.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/lib/orber/c_src/InitialReference.hh	2003-07-11 11:33:36.000000000 +0200
@@ -25,7 +25,20 @@
 #define _INITIALREFERENCE_HH
 #include <stdio.h>
 #include <string.h>
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#if HAVE_SSTREAM
+#include <sstream>
+typedef std::stringstream STRINGSTREAM;
+typedef std::stringbuf STRINGBUF;
+#else
 #include <strstream.h>
+typedef strstream STRINGSTREAM;
+typedef strstreambuf STRINGBUF;
+#endif
 
 class InitialReference {
 private:
@@ -35,8 +48,8 @@
 
   void enc_ushort(int s, char *byteArray);
   void enc_ulong(long l, char *byteArray);
-  void createIOR(strstream& byte, long length);
-  long align(strstreambuf* sbuf, long currentLength, int alignment);
+  void createIOR(STRINGSTREAM& byte, long length);
+  long align(STRINGBUF* sbuf, long currentLength, int alignment);
 
 public:
   InitialReference();
diff -aur --exclude='*.beam' --exclude=configure --exclude=Makefile otp_src_P9C_2003-07-10/lib/orber/c_src/inet.h otp_src_P9C_2003-07-10.fixed/lib/orber/c_src/inet.h
--- otp_src_P9C_2003-07-10/lib/orber/c_src/inet.h	1999-10-21 15:35:06.000000000 +0200
+++ otp_src_P9C_2003-07-10.fixed/lib/orber/c_src/inet.h	2003-07-11 11:05:03.000000000 +0200
@@ -36,4 +36,4 @@
 #define SERVICE "oiad"
 #define PROTO "tcp"
 
-#endif _inet_h
+#endif /* _inet_h */
